
exports.localization = {};
exports.localization.appName ={
  "en_US": "GeoGebra Classic",
  "ar": "جيوجبرا كلاسيك",
  "bg": "ГеоГебра Класик",
  "bs": "GeoGebra Classic",
  "ca": "GeoGebra Clàssic",
  "cs": "GeoGebra Klasik",
  "da": "Geogebra klassisk",
  "de": "GeoGebra Classic",
  "el": "Εφαρμογές Μαθηματικών",
  "es": "GeoGebra Clásico",
  "fa": "جئوجبرا کلاسیک",
  "fi": "GeoGebra Classic",
  "fr": "GeoGebra Classique",
  "hr": "Klasična GeoGebra",
  "hu": "GeoGebra Classic",
  "it": "GeoGebra Classico",
  "ja": "GeoGebra全機能版",
  "kk": "GeoGebra Classic",
  "ko": "지오지브라 클래식",
  "lt": "GeoGebra Classic",
  "mn": "Сонгодог Геогебра",
  "nl": "GeoGebra Klassiek",
  "no": "GeoGebra Classic",
  "no_NO": "GeoGebra klassisk",
  "no_NO_NY": "GeoGebra klassisk",
  "pl": "Math Calcs",
  "pt": "GeoGebra Classic",
  "ro": "GeoGebra Clasic",
  "ru": "GeoGebra Classic",
  "sk": "GeoGebra Classic",
  "sl": "Klasična GeoGebra",
  "sv": "GeoGebra Classic",
  "tr": "GeoGebra Klasik",
  "uk": "GeoGebra Класична",
  "vi": "GeoGebra Classic",
  "zh": "GeoGebra Classic",
  "zh_CN": "GeoGebra 经典",
  "zh_TW": "GeoGebra 經典版"};
